# coreapps-compatibility-layer

#### 介绍
CoreApps 多平台兼容层，包括CoreApps Platform的主要API，以及部分软件包的API

#### 软件架构

主软件包名为live_api.


#### 安装教程

    !如果您已安装CoreApps Platform 2022 LTS(而非DEV版！),那么您的Python中应该已自动安装了caplit-cl.可用pip list(不同平台可能不同)检查.

    打开终端,在检查好已安装pip后,使用pip安装caplit-cl-[平台名称*]

    *windows请输入nt,linux/macOS请输入linux


#### 参与贡献

如果您的软件需要使用capilt-cl进行不同平台兼容，请将api(而非主程序)提交Puul Request,通过后方可上架MoraStore.